Learn R Programming

bnpa (version 0.3.0)

check.outliers: Indentifies and gives an option to remove outliers

Description

This function receives a data set, scan all variables e for each one, verifies if there are outliers and ask if we wish to remove them. We can pass a parameter where we set if the function remove it automatically or will ask before.

Usage

check.outliers(data.to.work, ask.before)

Arguments

data.to.work

is a data set with variables to be checked.

ask.before

control if the process will ask for confirmation or not.

Examples

Run this code
# NOT RUN {
# Clean environment
closeAllConnections()
rm(list=ls())
# Set enviroment
# setwd("to your working directory")
# Load packages
library(bnpa)
# Load the data set
data(dataQuantC) # Pre-Loaded
# Set a variable to ask before remove outlier or not
ask.before = "Y" # or ask.before = "N"
# Call the procedure to check if there are outliers
dataQuantC <- check.outliers(dataQuantC, ask.before)
# }

Run the code above in your browser using DataLab